@@ -1,5 +1,13 @@
+$warnings = {}
+
 def warn(msg, from=nil)
-  error_output "WARNING: ".red + to_location(from) + msg + "\n"
+  warning = to_location(from) + msg
+
+  # don't do the same warning more than once (since code is parsed multiple times to handle auto input cases in engine/hs code gen
+  return if $warnings[warning]
+  $warnings[warning] = true
+
+  error_output "WARNING: ".red + warning + "\n"
 end
 
 def to_location(from)
