@@ -1,11 +1,11 @@
 require "set"
 
-def make_promises(ir2)
-  promises = ir2.map{|node|
-    arg_types = node.args.map{|a|ir2[a].type}
+def make_promises(ir3)
+  promises = ir3.map{|node|
+    arg_types = node.args.map{|a|ir3[a].type}
 
     impl = lambda{|*args|
-      $rank = node.way.vectorize ? node.way.mod : ir2[node.args[0]].rank
+      $rank = node.way.vectorize ? node.way.mod : ir3[node.args[0]].rank
       $at = arg_types[0]
       $bt = arg_types[1]
       node.way.impl[*args]
@@ -13,7 +13,11 @@ def make_promises(ir2)
 
     promise{
       args = node.args.map{|a| promises[a] }
-      zipn(node.zip_level, args, impl)
+      if node.way.name == "id"
+        args[0].value
+      else
+        zipn(node.zip_level, args, impl)
+      end
     }
   }
   promises
@@ -208,25 +212,6 @@ def pow(a,b)
   neg_exponent ? 1 / y : y
 end
 
-TestUnicodeChar = [1000].pack('U')
-ByteEncoding = Encoding::ISO8859_1
-begin
-  TestUnicodeChar.encode(Encoding.default_external)
-  def int_to_char(i)
-    begin
-      [i].pack("U")
-    rescue
-      raise IogiiError.new("char out of range %d" % i)
-    end
-  end
-rescue Encoding::UndefinedConversionError # (e.g. is ASCII)
-  # to work with values 128..255 which are invalid in regular ascii
-  Encoding.default_internal = Encoding.default_external = ByteEncoding
-  def int_to_char(i)
-    (i%256).chr
-  end
-end
-
 def prints(value)
   while !value.empty?
     v = value[0].value
@@ -615,7 +600,6 @@ def is_char_class(a, b)
 end
 
 def to_base(a,b)
-  raise IogiiError.new "base 0", nil if b==0
   to_base_h(a.abs,b,a<=>0)
 end
 
