@@ -1,3 +1,4 @@
+# $LOAD_PATH.unshift(__dir__)
 require_relative "./run.rb"
 
 if i=ARGV.index("--")
@@ -13,10 +14,10 @@ if ["-v", "--version"].any?{|option| ARGV.delete(option) }
 end
 
 pretty_print = ["-p", "--pretty_print"].any?{|option| ARGV.delete(option) }
-hs = ["-hs", "--hs"].any?{|option| ARGV.delete(option) }
+engine = ["-e", "--engine"].any?{|option| ARGV.delete(option) }
 
 def usage
-  raise IogiiError.new "usage: ruby #$0 -v,--version | [-p,--pretty_print] [-hs,--hs] <filename.iog> [-- rawargs*]"
+  raise IogiiError.new "usage: ruby #$0 -v,--version | [-p,--pretty_print] [-e,--engine] <filename.iog> [-- rawargs*]"
 end
 
 begin
@@ -35,7 +36,7 @@ begin
     program = IO.binread(ARGV[0])
   end
 
-  run_and_do_io(program, input, pretty_print, hs)
+  run_and_do_io(program, input, pretty_print, engine)
 rescue IogiiError => e
   STDERR.puts e.message
 rescue => e
