@@ -2,9 +2,9 @@ require 'stringio'
 require 'timeout'
 require "./run.rb"
 
-special_things = %w'$ ! > , : ; [ { f F m M i I e E nil del superpad implicit input version type show set let del  1,2,3 0,0 1,2,,3,4 "asdf" "" 1000'
+special_things = '$ ! > , : ; ] { f F m M i I e E nil del superpad implicit input version type show set let del = 1,2,3 0,0 1,2,,3,4 "asdf" "" 1000'.split
 
-all = ["\n",*' '..'~'] + special_things*3 + [" "]*2
+all = ["\n",*' '..'~'] + special_things*3
 
 # todo idea: take all tests and make larger programs that are almost correct
 # todo check that value matches type
@@ -32,3 +32,5 @@ n = 100000
     end
   }
 }
+
+puts "pass fuzz test"
\ No newline at end of file
