@@ -4,13 +4,15 @@ require "./run.rb"
 
 things = "a"," ","-","0","1",",","\n"
 
-def run_hs(prog, input)
+`ghc -O engine.hs`
+
+def run_engine(prog, input)
   File.open("prog.iog", "w"){|f| f << prog }
   if Array === input
-    `(ruby main.rb prog.iog -hs > test.hs && runhaskell test.hs #{input.map{|i|"'"+i+"'"}*" "}) 2>&1`
+    `(ruby main.rb prog.iog -e > test.ism && engine test.ism #{input.map{|i|"'"+i+"'"}*" "}) 2>&1`
   else
     File.open("input.txt", "w"){|f| f << input }
-    `(ruby main.rb prog.iog -hs > test.hs && runhaskell test.hs < input.txt) 2>&1`
+    `(ruby main.rb prog.iog -e > test.ism && engine test.ism < input.txt) 2>&1`
   end
 end
 
@@ -35,8 +37,9 @@ loop{
   $stdout = STDOUT
 
   puts "ruby output: %p" % [out]
-  out_hs = run_hs(program, input)
-  puts "haskell output: %p" % [out_hs]
+  out_hs = run_engine(program, input)
+  puts "engine output: %p" % [out_hs]
 
   exit if out != out_hs
 }
+
