@@ -3,7 +3,8 @@ File.open("prog.iog", "w"){|f| f << prog }
 output = `ruby main.rb prog.iog -- 9 10`
 raise output if output != "10\n11\n"
 
-output = `(ruby main.rb prog.iog -hs > test.hs && runhaskell test.hs 9 10) 2>&1`
+`ghc -O engine.hs`
+output = `(ruby main.rb prog.iog -e > test.ism && engine test.ism 9 10) 2>&1`
 raise output if output != "10\n11\n"
 
 prog = ",succ"
@@ -11,7 +12,7 @@ File.open("prog.iog", "w"){|f| f << prog }
 output = `ruby main.rb prog.iog -- 9 10`
 raise output if output != ":\n21\n"
 
-output = `(ruby main.rb prog.iog -hs > test.hs && runhaskell test.hs 9 10) 2>&1`
+output = `(ruby main.rb prog.iog -e > test.ism && engine test.ism 9 10) 2>&1`
 raise output if output != ":\n21\n"
 
 prog = "5>+"
@@ -19,4 +20,3 @@ File.open("prog.iog", "w"){|f| f << prog }
 output = `ruby main.rb prog.iog --`
 raise output if output != "10"
 
-`rm prog.iog test.hs`
