@@ -1,5 +1,5 @@
 def read_examples(filename)
-  File.read(filename).split(/\nname: ?/)[1..-1].map{|test|
+  ("\n"+File.read(filename)).split(/\nname: ?/)[1..-1].map{|test|
     name = test[/.*\n/]
     $'[/\noutput: ?/]
     expected = $'
