@@ -8,7 +8,7 @@ def read(file,red={})
     ""
   }
   puts "\n# #{file} " + "#" * (77 - file.length)
-  puts f
+  puts f.sub('<Header.hs>'){ File.read("Header.hs").gsub('\\\\'){'\\\\\\\\'} }
 end
 
 puts File.read("LICENSE.txt").gsub(/^/,"# ")
