@@ -99,7 +99,7 @@ def mk_op(names, type_sig, example="", block: false, vectorize: true, promote: t
   end
 
   puts type_sig.tdcode.gsub('btype','<a href="types.html#opswithtwogenerictypes">b</a>')
-  puts example.tdcode
+  puts example[0,35].tdcode
   puts "</tr>"
 end
 
